# learn-py-packaging
---

Example python package to demonstrate how to produce shareable code via GitHub and PyPI.

---

### Installation

*placeholder*

---

### Using code

Example:
```python
from learn_py_packaging import toy_module
print(toy_module.power(2,10))
```
